{% load relatives %}
<fieldset class="module aligned {{ fieldset.classes }}">
  {% if fieldset.name %}<h2>{{ fieldset.name }}</h2>{% endif %}
  {% if fieldset.description %}
      <div class="description">{{ fieldset.description|safe }}</div>
  {% endif %}
  {% for line in fieldset %}
    <div class="form-row{% if line.fields|length == 1 and line.errors %} errors{% endif %}{% for field in line %}{% if field.field.name %} field-{{ field.field.name }}{% endif %}{% endfor %}">
      {% if line.fields|length == 1 %}{{ line.errors }}{% endif %}
      {% for field in line %}
        <div{% if line.fields|length != 1 %} class="field-box{% if field.field.name %} field-{{ field.field.name }}{% endif %}{% if not field.is_readonly and field.errors %} errors{% endif %}"{% endif %}>
          {% if line.fields|length != 1 and not field.is_readonly %}{{ field.errors }}{% endif %}
          {% if field.is_checkbox %}
            {{ field.field }}{{ field.label_tag }}
          {% else %}
            {{ field.label_tag }}
            {% if field.is_readonly %}
              <p>{{ field|contents_or_fk_link|linebreaksbr }}</p>
            {% else %}
              {{ field.field }}
            {% endif %}
          {% endif %}
          {% if field.field.help_text %}
            <p class="help">{{ field.field.help_text|safe }}</p>
          {% endif %}
        </div>
      {% endfor %}
    </div>
  {% endfor %}
</fieldset>
