{% extends "admin/change_form.html" %}
{% load static relatives %}

{% block field_sets %}
{% related_objects adminform.form.instance as related_objects %}
<div class="module grp-module" id="filter">
    {% block relations %}
    <h2>Relations</h2>
    <ul>
        {% for related in related_objects %}
        <li>
            <a href="{{ related.url }}">{{ related.plural_name|capfirst }}</a>
        </li>
        {% endfor %}
    </ul>
    {% endblock relations %}
</div>
{{ block.super }}
{% endblock field_sets %}

{% block extrastyle %}
    {{ block.super }}
    <link href="{% static 'css/relatives.css' %}" rel="stylesheet">
{% endblock extrastyle %}
